<?php
/*
 * Plugin Name: Woocommerce XML Feeds
 * Plugin URI: https://www.persianscript.ir
 * Description: Create your own Woocommerce Feeds
 * Version: 1.1.14
 * Author: پرشین اسکریپت
 * Author URI: https://www.persianscript.ir
 * Requires at least: 5.5
 * Tested up to: 6.1.1
 * WC requires at least: 4.7
 * WC tested up to: 7.2.2
 * License: GPL2
 * Text Domain: wxf
 */

// Make sure we don't expose any info if called directly
if ( !function_exists( 'add_action' ) ) {
	echo 'Hi there!  I\'m just a plugin, not much I can do when called directly.';
	exit;
}

// Load plugin textdomain
add_action( 'plugins_loaded', 'wxf_load_textdomain' );
function wxf_load_textdomain() {
  load_plugin_textdomain( 'wxf', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
}

require_once('wc_xml_functions.php');

add_action( 'admin_enqueue_scripts', 'add_admin_scripts', 100, 1 );
function add_admin_scripts( $hook ) {

    global $post;

    if ( $hook == 'post-new.php' || $hook == 'post.php' ) {
        if ( 'wc_xml_feeds' === $post->post_type ) {     
            wp_enqueue_script(  'woofeedsjs', plugin_dir_url( __FILE__ ).'assets/woo_xml_feed.js' );
			wp_enqueue_script( 'selectWoo' );
			wp_enqueue_style( 'woocommerce_admin_styles' );
        }
    }
}


add_action('admin_head', 'woo_xml_custom_admin_style');
function woo_xml_custom_admin_style() {
  echo '<style>
    .column-xml_id {
		width: 55px;
	}
  </style>';
}

function wxf_elements() {
  
  global $post;
  
  $product_cat_terms = get_terms( 'product_cat', array(
    'hide_empty' => false,
  ) );
  $selected_wc_xml_product_cat = get_post_meta($post->ID, 'wc_xml_product_cat', true);
  
  $product_cats_drop = '<select multiple="multiple" id="wc_xml_product_cat" name="wc_xml_product_cat[]" style="width: 50%;">';
  
  foreach($product_cat_terms as $product_cat_term) {
    $product_cats_drop .= '<option value="'. $product_cat_term->term_id .'" '. (!empty($selected_wc_xml_product_cat) && in_array($product_cat_term->term_id, $selected_wc_xml_product_cat) ? 'selected="selected"' : '') .'>'. $product_cat_term->name.'</option>';
  }
  $product_cats_drop .= '</select>';
  
  $product_cats_action = '
    <select id="wc_xml_product_categories_action" name="wc_xml_product_categories_action" style="width: 50%;">
      <option value="NOT IN" '. (get_post_meta($post->ID, 'wc_xml_product_categories_action', true) == 'NOT IN' ? 'selected="selected"' : '') .' >'. __('exclude', 'wxf') .'</option>
      <option value="IN" '. (get_post_meta($post->ID, 'wc_xml_product_categories_action', true) == 'IN' ? 'selected="selected"' : '') .' >'. __('include', 'wxf') .'</option>
    </select>
  ';
  
  $elements = array(
  
    'wc_xml_header' => array('type'=> 'textarea', 'label' => __('Feed Header', 'wxf')),
    'wc_xml_main' => array('type'=> 'textarea', 'label' => __('Feed Main', 'wxf')),
    'wc_xml_images' => array('type'=> 'textarea', 'label' => __('Feed Images', 'wxf')),
    'wc_xml_attributes' => array('type'=> 'textarea', 'label' => __('Feed Attributes', 'wxf')),
    'wc_xml_attributes_implode' => array('type'=> 'checkbox', 'label' => __('Create one product based on the parent for variable products. Add all variations attributes in a comma separated tag', 'wxf')),
    'wc_xml_parent_replace' => array('type'=> 'checkbox', 'label' => __('Use main/parent product excerpt and description if variation data is empty', 'wxf')),
    'wc_xml_attributes_title' => array('type'=> 'checkbox', 'label' => __('Append attribute to the title of the product', 'wxf')),
    'wc_xml_footer' => array('type'=> 'textarea', 'label' => __('Feed Footer', 'wxf')),
    'wc_xml_instock_msg' => array('type'=> 'text', 'label' => __('Availability message when in stock', 'wxf')),
    'wc_xml_outofstock_msg' => array('type'=> 'text', 'label' => __('Availability message when NOT in stock', 'wxf')),
    'wc_xml_backorder_msg' => array('type'=> 'text', 'label' => __('Availability message when in Backorder', 'wxf')),
    'wc_xml_default_brand' => array('type'=> 'text', 'label' => __('Default brand', 'wxf')),
    'wc_xml_displayoutofstock' => array('type'=> 'checkbox', 'label' => __('Display product when out of stock', 'wxf')),
    'wc_xml_disbreadcrumb' => array('type'=> 'checkbox', 'label' => __('Display parent categories', 'wxf')),
    'wc_xml_breadcrumbsep' => array('type'=> 'text', 'label' => __('Seperator character for parent categories', 'wxf')),
    'wc_xml_product_categories' => array('type'=> 'select', 'label' => __('Products in categories', 'wxf'), 'id' => 'wc_xml_product_cat', 'result' => $product_cats_drop),
    'wc_xml_product_categories_action' => array('type'=> 'select', 'label' => __('Categories action', 'wxf'), 'id' => 'wc_xml_product_categories_action', 'result' => $product_cats_action),
    'wc_xml_filename' => array('type'=> 'text', 'label' => __('Cached filename', 'wxf'), 'prefix' => get_site_url().'/'),
    'wc_xml_plain' => array('type'=> 'checkbox', 'label' => __('Output as plain text / remove xml headers', 'wxf')),
    'wc_xml_save' => array('type'=> 'checkbox', 'label' => __('Save cached file on publish/update', 'wxf')),
  
  );
  
  return $elements;
}

add_action( 'init', 'create_wc_xml_feed' );

function create_wc_xml_feed() {
    register_post_type( 'wc_xml_feeds',
        array(
            'labels' => array(
                'name'          => __('WOO Feeds', 'wxf'),
                'singular_name' => __('WOO Feed', 'wxf'),
                'add_new'       => __('Add New', 'wxf'),
                'add_new_item'  => __('Add New WOO Feed', 'wxf'),
                'edit'          => __('Edit', 'wxf'),
                'edit_item'     => __('Edit WOO Feed', 'wxf'),
                'new_item'      => __('New WOO Feed', 'wxf'),
                'view'          => __('View', 'wxf'),
                'view_item'     => __('View WOO Feed', 'wxf'),
                'search_items'  => __('Search WOO Feeds', 'wxf'),
                'not_found'     => __('No WOO Feed found', 'wxf'),
                'not_found_in_trash' => __('No WOO Feeds found in Trash', 'wxf'),
                'parent'        => __('Parent WOO Feed', 'wxf')
            ),
 
            'public' => true,
            'menu_position' => 56,
            'rewrite' => array('slug' => 'xmlfeeds'),
            'supports' => array( 'title'),
            'taxonomies' => array( 'slug' ),
            'menu_icon' => plugins_url( 'images/image.png', __FILE__ ),
            'has_archive' => false,
            'exclude_from_search' => true
        )
    );
}

add_action( 'admin_init', 'wc_xml_feed_admin' );
function wc_xml_feed_admin() {
    add_meta_box( 'wc_xml_feed_meta_box',
        'WooCommerce Feed parts',
        'display_wc_xml_feed_meta_box',
        'wc_xml_feeds', 'normal', 'high'
    );
}

function display_wc_xml_feed_meta_box( $wc_xml_feed ) {
  
  $elements = wxf_elements();
  ?>
  <div class="main_meta_wrap">
  <?php
  foreach ($elements as $key => $element) {
    ?>
    <p>
      <label for="<?php echo $key; ?>"><?php echo $element['label']; ?></label>
    <?php
    
    if ($element['type'] == 'textarea') {
      ?><br />
      
      
      <textarea style="width: 100%; height: 280px;" id="<?php echo $key; ?>" class="<?php echo $key; ?>" name="<?php echo $key; ?>"><?php echo get_post_meta( $wc_xml_feed->ID, $key, true ); ?></textarea> <br />
      
      <?php
    }
    
    if ($element['type'] == 'text') {
      ?>
	  <br />
	  <?php
        if (isset($element['prefix']) && $element['prefix'] != '') {
          $inputstyle = '';
          ?>
          <span><?php echo $element['prefix']; ?></span>
          <?php
        } else {
          $inputstyle = 'width: 100%;';
        }
      ?>
      <input type="text" style="<?php echo $inputstyle; ?>" name="<?php echo $key; ?>" value="<?php echo get_post_meta( $wc_xml_feed->ID, $key, true ); ?>" /><br />
      <?php
      if (isset($element['suffix']) && $element['suffix'] != '') {

        ?>
        <span><?php echo $element['suffix']; ?></span>
        <?php
      }
    }
    
    if ($element['type'] == 'checkbox') {
      ?>

      <input type="checkbox" style="" name="<?php echo $key; ?>" value="on" <?php echo (get_post_meta( $wc_xml_feed->ID, $key, true ) == 'on' ? 'checked' : ''); ?> /><br />
      
      <?php
    } 
    if ($element['type'] == 'select') {
      echo '<br />'.$element['result'];
      echo '
      <script>
        jQuery(document).ready(function() {
          jQuery("#'. $element['id'] .'").selectWoo({
            allowClear: true
          });
        });
      </script>
      ';
      
    }    
    ?>
    </p>
    <?php
  }
  
  $wc_xml_cached_url = get_post_meta($wc_xml_feed->ID, 'wc_xml_cached_url', true);
  $absolute_path = get_home_path().str_replace( get_site_url().'/', '', $wc_xml_cached_url );
  
  if ( get_post_meta($wc_xml_feed->ID, 'wc_xml_last_cached', true) != '' ) {
    echo '
	<div class="last_cached"><label>'.__('Last Cached', 'wxf') .'</label> 
		<span class="cached_date_info">'. ( file_exists( $absolute_path ) === true ? date_i18n( get_option( 'date_format' ) .' '. get_option( 'time_format' ), get_post_meta($wc_xml_feed->ID, 'wc_xml_last_cached', true ) ) : '' ) .'</span>
	</div>';
  }
  
  if ( $wc_xml_cached_url != '' ) {
    echo '
      <div class="cached_url">
        <label>'.__('Visit the cached file', 'wxf') .'</label> 
        <a href="'. $wc_xml_cached_url .'" target="_blank">'. ( file_exists( $absolute_path ) === true ? $wc_xml_cached_url : '' ) .'</a>
        <span class="filesize" >'. ( file_exists( $absolute_path ) === true ? '('. round(filesize( $absolute_path ) / 1024 / 1024, 2) .' MB)' : __( 'File is missing?', 'wxf' ) ) .'</span>
      </div>';
  }
  
  
 
  if ( get_post_meta( $wc_xml_feed->ID, 'wc_xml_filename', true ) != '' ) {
	  
	
		
	$selected_wc_xml_product_cat = get_post_meta( $wc_xml_feed->ID, 'wc_xml_product_cat', true);
	
	$tax_args = array();
	if (!empty( $selected_wc_xml_product_cat ) ) {
		$tax_args = array(
			array(
				'taxonomy' => 'product_cat',
				'field'    => 'id',
				'terms'    => $selected_wc_xml_product_cat,
				'operator' => get_post_meta( $wc_xml_feed->ID, 'wc_xml_product_categories_action', true),
			),
		);
	}
	
	$args = array( 
		'posts_per_page' 	=> -1,
		'suppress_filters' 	=> false,
		'fields' 			=> 'ids',
		'post_type' 		=> array( 'product' ),
		'post_status' 		=> 'publish',
		'tax_query' 		=> $tax_args,
	 );
	

	$products_q = get_posts( $args );

	
	$count = count( $products_q );
	
	  
    echo '
      <div class="regenerate_xml">
        <label>'.__('(Re)generate Cached XML', 'wxf') .'</label> 
        <a href="#" class="button" data-count="'. $count .'" data-batch="'. apply_filters( 'wxf_batch_size', 100, $wc_xml_feed->ID ) .'" data-xml="'. $wc_xml_feed->ID .'" data-offset="0" id="wxf_regenerate_xml">'. __('(Re)generate XML', 'wxf') .'  ('. $count .' '. __( 'products', 'wxf' ) .')</a> &nbsp;&nbsp;<small>'. __('Use this if generating via publish fails', 'wxf') .'</small>
      </div>
	  <div class="regenerate_progress">
			<span class="regenerate_pc">0%</span>
			<div class="regenerate_progress_inner"></div>
		</div>
	  
	  ';
  }
  ?>
  </div>
  <style>
    .main_meta_wrap label { 
		font-weight: bold; 
		display: inline-block; 
		min-width: 180px; 
	}
	.regenerate_xml {
		margin-top: 10px;
	}
	.regenerate_progress {
		height: 40px; 
		margin-top: 20px; 
		clear: both; 
		text-align: center; 
		position: relative; 
		border: 1px solid #42c494; 
		display: none;
	}
	.regenerate_pc {
		z-index: 10; 
		position: absolute; 
		display: block; 
		width: 100%;
		top: 8px;
		font-size: 18px;
		color: #0c4026;
	}
	.regenerate_progress_inner {
		box-sizing: border-box;
		height: 40px;
		padding: 10px;
		background-color: #90dcc0;
		width: 0;
		max-width: 100%;
		position: absolute;
		top: 0;
		left: 0;
	}
  </style>
  <?php
  
}

// save fields
add_action( 'save_post', 'add_wc_xml_feed_fields', 10, 2 );
function add_wc_xml_feed_fields( $wc_xml_feed_id, $wc_xml_feed ) {
  if ( $wc_xml_feed->post_type == 'wc_xml_feeds' ) {
  
	remove_action( 'save_post', 'add_wc_xml_feed_fields', 10);
   
    if ( isset( $_POST['wc_xml_header'] ) && $_POST['wc_xml_header'] != '' ) { 
		update_post_meta( $wc_xml_feed_id, 'wc_xml_header', $_POST['wc_xml_header'] ); 
	} else {
		delete_post_meta( $wc_xml_feed_id, 'wc_xml_header' );
	}
    if ( isset( $_POST['wc_xml_main'] ) && $_POST['wc_xml_main'] != '' ) { 
		update_post_meta( $wc_xml_feed_id, 'wc_xml_main', $_POST['wc_xml_main'] ); 
	} else {
		delete_post_meta( $wc_xml_feed_id, 'wc_xml_main' );
	}
    if ( isset( $_POST['wc_xml_images'] ) && $_POST['wc_xml_images'] != '' ) { 
		update_post_meta( $wc_xml_feed_id, 'wc_xml_images', $_POST['wc_xml_images'] ); 
	} else {
		delete_post_meta( $wc_xml_feed_id, 'wc_xml_images' ); 
	}
    if ( isset( $_POST['wc_xml_attributes'] ) && $_POST['wc_xml_attributes'] != '' ) { 
		update_post_meta( $wc_xml_feed_id, 'wc_xml_attributes', $_POST['wc_xml_attributes'] ); 
	} else {
		delete_post_meta( $wc_xml_feed_id, 'wc_xml_attributes' );
	}
    if ( isset( $_POST['wc_xml_attributes_implode'] ) && $_POST['wc_xml_attributes_implode'] != '' ) { 
		update_post_meta( $wc_xml_feed_id, 'wc_xml_attributes_implode', $_POST['wc_xml_attributes_implode'] ); 
	} else {
		delete_post_meta( $wc_xml_feed_id, 'wc_xml_attributes_implode' ); 
	}
    if ( isset( $_POST['wc_xml_parent_replace'] ) && $_POST['wc_xml_parent_replace'] != '' ) { 
		update_post_meta( $wc_xml_feed_id, 'wc_xml_parent_replace', $_POST['wc_xml_parent_replace'] ); 
	} else {
		delete_post_meta( $wc_xml_feed_id, 'wc_xml_parent_replace' ); 
	}
    if ( isset( $_POST['wc_xml_attributes_title'] ) && $_POST['wc_xml_attributes_title'] != '' ) {  
		update_post_meta( $wc_xml_feed_id, 'wc_xml_attributes_title', $_POST['wc_xml_attributes_title'] ); 
	} else {
		delete_post_meta( $wc_xml_feed_id, 'wc_xml_attributes_title' ); 
	}
    if ( isset( $_POST['wc_xml_footer'] ) && $_POST['wc_xml_footer'] != '' ) { 
		update_post_meta( $wc_xml_feed_id, 'wc_xml_footer', $_POST['wc_xml_footer'] ); 
	} else {
		delete_post_meta( $wc_xml_feed_id, 'wc_xml_footer' ); 
	}
    if ( isset( $_POST['wc_xml_instock_msg'] ) && $_POST['wc_xml_instock_msg'] != '' ) { 
		update_post_meta( $wc_xml_feed_id, 'wc_xml_instock_msg', $_POST['wc_xml_instock_msg'] ); 
	} else {
		delete_post_meta( $wc_xml_feed_id, 'wc_xml_instock_msg' ); 
	}
    if ( isset( $_POST['wc_xml_outofstock_msg'] ) && $_POST['wc_xml_outofstock_msg'] != '' ) { 
		update_post_meta( $wc_xml_feed_id, 'wc_xml_outofstock_msg', $_POST['wc_xml_outofstock_msg'] ); 
	} else {
		delete_post_meta( $wc_xml_feed_id, 'wc_xml_outofstock_msg' );
	}
    if ( isset( $_POST['wc_xml_backorder_msg'] ) && $_POST['wc_xml_backorder_msg'] != '' ) { 
		update_post_meta( $wc_xml_feed_id, 'wc_xml_backorder_msg', $_POST['wc_xml_backorder_msg'] ); 
	} else {
		delete_post_meta( $wc_xml_feed_id, 'wc_xml_backorder_msg' );
	}
    if ( isset( $_POST['wc_xml_default_brand'] ) && $_POST['wc_xml_default_brand'] != '' ) { 
		update_post_meta( $wc_xml_feed_id, 'wc_xml_default_brand', $_POST['wc_xml_default_brand'] ); 
	} else {
		delete_post_meta( $wc_xml_feed_id, 'wc_xml_default_brand' );
	}
    if ( isset( $_POST['wc_xml_product_cat'] ) && $_POST['wc_xml_product_cat'] != '' ) { 
		update_post_meta( $wc_xml_feed_id, 'wc_xml_product_cat', $_POST['wc_xml_product_cat'] ); 
	} else { 
		delete_post_meta( $wc_xml_feed_id, 'wc_xml_product_cat' ); 
	}
    if ( isset( $_POST['wc_xml_product_categories_action'] ) && !empty($_POST['wc_xml_product_categories_action']) ) { 
		update_post_meta( $wc_xml_feed_id, 'wc_xml_product_categories_action', $_POST['wc_xml_product_categories_action'] ); 
	} else {
		delete_post_meta( $wc_xml_feed_id, 'wc_xml_product_categories_action' );
	}
    if ( isset( $_POST['wc_xml_displayoutofstock'] ) && !empty($_POST['wc_xml_displayoutofstock']) ) { 
		update_post_meta( $wc_xml_feed_id, 'wc_xml_displayoutofstock', $_POST['wc_xml_displayoutofstock'] ); 
	} else {
		delete_post_meta( $wc_xml_feed_id, 'wc_xml_displayoutofstock' ); 
	}
    if ( isset( $_POST['wc_xml_disbreadcrumb'] ) && !empty($_POST['wc_xml_disbreadcrumb']) ) { 
		update_post_meta( $wc_xml_feed_id, 'wc_xml_disbreadcrumb', $_POST['wc_xml_disbreadcrumb'] ); 
	} else {
		delete_post_meta( $wc_xml_feed_id, 'wc_xml_disbreadcrumb' );
	}
    if ( isset( $_POST['wc_xml_breadcrumbsep'] ) && $_POST['wc_xml_breadcrumbsep'] != '' ) { 
		update_post_meta( $wc_xml_feed_id, 'wc_xml_breadcrumbsep', $_POST['wc_xml_breadcrumbsep'] ); 
	} else {
		delete_post_meta( $wc_xml_feed_id, 'wc_xml_breadcrumbsep' );
	}
    if (isset( $_POST['wc_xml_plain'] ) && $_POST['wc_xml_plain'] != '' ) {
      update_post_meta( $wc_xml_feed_id, 'wc_xml_plain', $_POST['wc_xml_plain'] );
    } else {
      delete_post_meta( $wc_xml_feed_id, 'wc_xml_plain' );
    }
    if ( isset( $_POST['wc_xml_filename'] ) && $_POST['wc_xml_filename'] != '' ) { 

      update_post_meta( $wc_xml_feed_id, 'wc_xml_filename', $_POST['wc_xml_filename'] );
      
      if (isset( $_POST['wc_xml_save'] ) && $_POST['wc_xml_save'] != '' ) {
        file_put_contents(get_home_path().esc_sql($_POST['wc_xml_filename']), wcxml_out($wc_xml_feed_id));
        update_post_meta( $wc_xml_feed_id, 'wc_xml_last_cached', date_i18n('U'));
        update_post_meta( $wc_xml_feed_id, 'wc_xml_cached_url', get_site_url().'/'.esc_sql($_POST['wc_xml_filename']));
      }
      
    }
    
	
	add_action( 'save_post', 'add_wc_xml_feed_fields', 10, 2 );
    
  }
}

// add template support

add_filter( 'template_include', 'wc_xml_feed_include_template_function', 99 );
function wc_xml_feed_include_template_function( $template_path ) {
    global $post;
  
    if ( get_post_type() == 'wc_xml_feeds' ) {
        if ( is_single() ) {
            // checks if the file exists in the theme first,
            // otherwise serve the file from the plugin
            if ( $theme_file = locate_template( array ( 'single-wc_xml_feed.php' ) ) ) {
                $template_path = $theme_file;
            } else {
                $template_path = plugin_dir_path( __FILE__ ) . '/single-wc_xml_feed.php';
            }
        }
    }
    return $template_path;
}

function wc_xml_feed_activate() {
  
    // register post type
    create_wc_xml_feed();
    
    // flush rewrite rules
    flush_rewrite_rules();
    
    $post = array(
      'post_name' => 'skroutz',
      'post_status' => 'publish',
      'post_type' => 'wc_xml_feeds',
      'post_title' => 'Skroutz.gr'
    );
    
    $wc_xml_feed_id = wp_insert_post( $post );

    $wc_xml_header = '<?xml version="1.0" encoding="UTF-8"?>
  <mywebstore>
    <created_at>{datetime}</created_at>
      <products>';
    
    $wc_xml_main = '
<product id="{id}">
    <UniqueID>{id}</UniqueID>
    <name><![CDATA[{name} - {brand}]]></name>
    <link><![CDATA[{link}]]></link>
    <image><![CDATA[{image}]]></image>
    {images}
    <category><![CDATA[{categories}]]></category>
    <category_path><![CDATA[{categories_tree}]]></category_path>
    <price>{price}</price>
    <availability>{availability}</availability>
    <manufacturer><![CDATA[{brand}]]></manufacturer>
    <instock>{stock_status}</instock>
    {attributes}
</product>';

    $wc_xml_images = '<additional_imageurl>{image}</additional_imageurl>';
    $wc_xml_attributes = '<{attribute_label}>{attribute_value}</{attribute_label}>';
    $wc_xml_footer = '</products>
</mywebstore>';

    $wc_xml_instock_msg = 'Available in store / Delivery 1 to 3 days';
    $wc_xml_outofstock_msg = 'Upon order';
    $wc_xml_backorder_msg = 'In backorder';
    $wc_xml_default_brand = 'OEM';
    
    update_post_meta( $wc_xml_feed_id, 'wc_xml_header', $wc_xml_header ); 
    update_post_meta( $wc_xml_feed_id, 'wc_xml_main', $wc_xml_main ); 
    update_post_meta( $wc_xml_feed_id, 'wc_xml_images', $wc_xml_images ); 
    update_post_meta( $wc_xml_feed_id, 'wc_xml_attributes', $wc_xml_attributes ); 
    update_post_meta( $wc_xml_feed_id, 'wc_xml_attributes_implode', 'on' );
    update_post_meta( $wc_xml_feed_id, 'wc_xml_parent_replace', 'on' );
    update_post_meta( $wc_xml_feed_id, 'wc_xml_attributes_title', '' );
    update_post_meta( $wc_xml_feed_id, 'wc_xml_footer', $wc_xml_footer ); 
    update_post_meta( $wc_xml_feed_id, 'wc_xml_instock_msg', $wc_xml_instock_msg ); 
    update_post_meta( $wc_xml_feed_id, 'wc_xml_outofstock_msg', $wc_xml_outofstock_msg );
    update_post_meta( $wc_xml_feed_id, 'wc_xml_backorder_msg', $wc_xml_backorder_msg );
    update_post_meta( $wc_xml_feed_id, 'wc_xml_default_brand', $wc_xml_default_brand );
    update_post_meta( $wc_xml_feed_id, 'wc_xml_displayoutofstock', 'on' );
    update_post_meta( $wc_xml_feed_id, 'wc_xml_plain', '' );
    update_post_meta( $wc_xml_feed_id, 'wc_xml_disbreadcrumb', 'on' );
    update_post_meta( $wc_xml_feed_id, 'wc_xml_breadcrumbsep', ' > ' );
    update_post_meta( $wc_xml_feed_id, 'wc_xml_filename', 'skroutz.xml' );
	
	
	/**** CREATE FB Sample ****/
	
	$post = array(
      'post_name' => 'facebook',
      'post_status' => 'publish',
      'post_type' => 'wc_xml_feeds',
      'post_title' => 'Facebook Sample'
    );
    
    $wc_xml_feed_id = wp_insert_post( $post );

    $wc_xml_header = '<?xml version="1.0" encoding="UTF-8"?>
<rss xmlns:g="http://base.google.com/ns/1.0" version="2.0">
<created_at>{datetime}</created_at>
<channel>
    <title>Test Store</title>
    <link>http://www.example.com</link>
    <description>An example item from the feed</description>
';
    
    $wc_xml_main = '
<item>
    <id>{id}</id>
    <title><![CDATA[{name}]]></title>
    <description>{facebook_description}</description>
    <availability>{availability}</availability>
    <condition>new</condition>
    <price>{price} {currency}</price>
    <link><![CDATA[{link}]]></link>
    <image_link><![CDATA[{image}]]></image_link>
    <additional_image_link></additional_image_link>
    <brand><![CDATA[{brand}]]></brand>
    <inventory>{stock_quantity}</inventory>
    <visibility>{fb_visibility}</visibility>
</item>
';

    $wc_xml_images = '{image},';
    $wc_xml_attributes = '<{attribute_label}>{attribute_value}</{attribute_label}>';
    $wc_xml_footer = '    </channel>
</rss>';

    $wc_xml_instock_msg = 'in stock';
    $wc_xml_outofstock_msg = 'available for order';
    $wc_xml_backorder_msg = 'in backorder';
    $wc_xml_default_brand = 'OEM';
    
    update_post_meta( $wc_xml_feed_id, 'wc_xml_header', $wc_xml_header ); 
    update_post_meta( $wc_xml_feed_id, 'wc_xml_main', $wc_xml_main ); 
    update_post_meta( $wc_xml_feed_id, 'wc_xml_images', $wc_xml_images ); 
    update_post_meta( $wc_xml_feed_id, 'wc_xml_attributes', $wc_xml_attributes ); 
    update_post_meta( $wc_xml_feed_id, 'wc_xml_attributes_implode', 'on' );
    update_post_meta( $wc_xml_feed_id, 'wc_xml_parent_replace', 'on' );
    update_post_meta( $wc_xml_feed_id, 'wc_xml_attributes_title', '' );
    update_post_meta( $wc_xml_feed_id, 'wc_xml_footer', $wc_xml_footer ); 
    update_post_meta( $wc_xml_feed_id, 'wc_xml_instock_msg', $wc_xml_instock_msg ); 
    update_post_meta( $wc_xml_feed_id, 'wc_xml_outofstock_msg', $wc_xml_outofstock_msg );
    update_post_meta( $wc_xml_feed_id, 'wc_xml_backorder_msg', $wc_xml_backorder_msg );
    update_post_meta( $wc_xml_feed_id, 'wc_xml_default_brand', $wc_xml_default_brand );
    update_post_meta( $wc_xml_feed_id, 'wc_xml_displayoutofstock', '' );
    update_post_meta( $wc_xml_feed_id, 'wc_xml_plain', '' );
    update_post_meta( $wc_xml_feed_id, 'wc_xml_disbreadcrumb', '' );
    update_post_meta( $wc_xml_feed_id, 'wc_xml_breadcrumbsep', ' > ' );
    update_post_meta( $wc_xml_feed_id, 'wc_xml_filename', 'fb.xml' );
    
    
    if (! wp_next_scheduled ( 'wxf_cronjob' )) {
      wp_schedule_event(time(), 'daily', 'wxf_cronjob');
    }
    
}

register_activation_hook( __FILE__, 'wc_xml_feed_activate' );

// this will run daily
add_action('wxf_cronjob', 'wxf_cronjob_func');
function wxf_cronjob_func() {
	
	ini_set('default_socket_timeout', 900); // 900 Seconds = 15 Minutes
	ini_set('memory_limit','4096M');

	require_once(ABSPATH . 'wp-admin/includes/file.php');
  
	$args = array(
		'post_type'       => 'wc_xml_feeds',
		'posts_per_page'  =>  -1,
		'nopaging'        => true,
		'fields'          => 'ids',
		'post_status'     => 'publish'
	);

	$query = new WP_Query( $args );  

	if ($query->post_count > 0) {
		foreach($query->posts as $wc_xml_feed_id) {
			$wc_xml_filename = '';
			$wc_xml_filename = esc_sql(get_post_meta( $wc_xml_feed_id, 'wc_xml_filename', true ));

			file_put_contents(get_home_path().'xmlupdate.txt', date( 'Y-m-d H:i:s' ));
			file_put_contents(get_home_path().$wc_xml_filename, wcxml_out($wc_xml_feed_id));
			update_post_meta( $wc_xml_feed_id, 'wc_xml_last_cached', date_i18n('U'));
			update_post_meta( $wc_xml_feed_id, 'wc_xml_cached_url', get_site_url().'/'.$wc_xml_filename);
		}
	}
}

register_deactivation_hook(__FILE__, 'wfx_deactivation');

function wfx_deactivation() {
	wp_clear_scheduled_hook('wxf_cronjob');
}


// add helper metabox

function wooxml_register_meta_box() {
    add_meta_box(
        'wooxml',
        esc_html__( 'Available Tags', 'wxf' ),
        'wooxml_meta_box',
        'wc_xml_feeds',
        'side',
        'default'
        );
}
add_action( 'admin_init', 'wooxml_register_meta_box' );

function wooxml_meta_box() {
  global $post;
  ?>
  <pre class="elements">
  <strong><small><?php echo  __('For the Header and Footer area only', 'wxf'); ?></strong></small>
  <a href="#" data-target="wc_xml_header">{datetime}</a>
  <a href="#" data-target="wc_xml_header">{site_title}</a>
  <a href="#" data-target="wc_xml_header">{site_url}</a>
  <a href="#" data-target="wc_xml_header">{site_description}</a>
  <hr />
  <strong><small><?php echo  __('For the Main area only', 'wxf'); ?></strong></small>
  <a href="#" data-target="wc_xml_main">{datetime}</a>
  <a href="#" data-target="wc_xml_main">{id}</a>
  <a href="#" data-target="wc_xml_main">{name}</a>
  <a href="#" data-target="wc_xml_main">{link}</a>
  <a href="#" data-target="wc_xml_main">{image}</a>
  <a href="#" data-target="wc_xml_main">{categories_tree}</a>
  <a href="#" data-target="wc_xml_main">{categories}</a>
  <a href="#" data-target="wc_xml_main">{price_with_tax}</a>
  <a href="#" data-target="wc_xml_main">{price_without_tax}</a>
  <a href="#" data-target="wc_xml_main">{regular_price}</a>
  <a href="#" data-target="wc_xml_main">{sales_price}</a>
  <a href="#" data-target="wc_xml_main">{price}</a>
  <a href="#" data-target="wc_xml_main">{display_price}</a>
  <a href="#" data-target="wc_xml_main">{price_suffix}</a>
  <a href="#" data-target="wc_xml_main">{currency}</a>
  <a href="#" data-target="wc_xml_main">{sku}</a>
  <a href="#" data-target="wc_xml_main">{description}</a>
  <a href="#" data-target="wc_xml_main">{facebook_description}</a>
  <a href="#" data-target="wc_xml_main">{excerpt}</a>
  <a href="#" data-target="wc_xml_main">{weight}</a>
  <a href="#" data-target="wc_xml_main">{weight_unit}</a>
  <a href="#" data-target="wc_xml_main">{height}</a>
  <a href="#" data-target="wc_xml_main">{width}</a>
  <a href="#" data-target="wc_xml_main">{length}</a>
  <a href="#" data-target="wc_xml_main">{dimension_unit}</a>
  <a href="#" data-target="wc_xml_main">{tags_tree}</a>
  <a href="#" data-target="wc_xml_main">{tags}</a>
  <a href="#" data-target="wc_xml_main">{stock}</a>
  <a href="#" data-target="wc_xml_main">{stock_status}</a>
  <a href="#" data-target="wc_xml_main">{stock_quantity}</a>
  <a href="#" data-target="wc_xml_main">{total_stock}</a>
  <a href="#" data-target="wc_xml_main">{tax_status}</a>
  <a href="#" data-target="wc_xml_main">{tax_class}</a>
  <a href="#" data-target="wc_xml_main">{avarage_rating}</a>
  <a href="#" data-target="wc_xml_main">{rating_count}</a>
  <a href="#" data-target="wc_xml_main">{review_count}</a>
  <a href="#" data-target="wc_xml_main">{featured}</a>
  <a href="#" data-target="wc_xml_main">{backorders}</a>
  <a href="#" data-target="wc_xml_main">{visibility}</a>
  <a href="#" data-target="wc_xml_main">{fb_visibility}</a>
  <a href="#" data-target="wc_xml_main">{availability}</a>
  <a href="#" data-target="wc_xml_main">{product_type}</a>
  <a href="#" data-target="wc_xml_main">{is_purchasable}</a>
  <a href="#" data-target="wc_xml_main">{shipping_class}</a>
  <a href="#" data-target="wc_xml_main">{shipping_class_label}</a>
  <a href="#" data-target="wc_xml_main">{brand}</a>
  <a href="#" data-target="wc_xml_main">{images}</a>
  <a href="#" data-target="wc_xml_main">{attributes}</a>
  
  <?php
    
    $wooxml_get_taxonomies = wooxml_get_taxonomies();
    if (!empty($wooxml_get_taxonomies)) {
      
      echo  '<strong>'.__('Custom Taxonomies', 'wxf').'</strong>';
      
      foreach($wooxml_get_taxonomies as $t) {
        
        echo "\n".'  <a href="#" data-target="wc_xml_main">{tax_'. $t .'}</a>';
        
      }
      
    }
  
  ?>
  
  
  --
  <?php echo  __('Any custom meta wrapped in %%', 'wxf')."\n"; ?>
  {%%custom_meta_key%%}
  --
  Found meta keys:
  
  <?php
    
    $nitro_get_product_meta_keys = nitro_get_product_meta_keys();
	
	if ( !empty( $nitro_get_product_meta_keys ) ) {
		foreach($nitro_get_product_meta_keys as $mkey) {
			echo '<a href="#" data-target="wc_xml_main">{%%'. $mkey .'%%}</a>
  ';
		}
    }
  
  ?>
  <hr />
  <strong><small><?php echo  __('For the Attributes area only', 'wxf'); ?></strong></small>
  <a href="#" data-target="wc_xml_attributes">{attribute_label}</a>
  <a href="#" data-target="wc_xml_attributes">{attribute_value}</a>
  <hr />
  <strong><small><?php echo  __('For the Images area only', 'wxf'); ?></strong></small>
  <a href="#" data-target="wc_xml_images">{image}</a>
  </pre>
  <?php
  
}

// Display Fields
add_action( 'woocommerce_product_options_general_product_data', 'wooxml_add_custom_general_fields' );
function wooxml_add_custom_general_fields() {

  global $woocommerce, $post;
  
  $saved_options = get_post_meta($post->ID, 'wooxml_exclude', true);
  
  if ( !is_array( $saved_options ) ) {
	  $saved_options = explode( ',', str_replace( ', ', ',', $saved_options ) );
  }
  
  // get woo xml entries
  $args = array(
    'posts_per_page'  => -1,
    'nopaging'        => true,
    'post_type'       => 'wc_xml_feeds',
    'orderby'         => 'title',
    'order'           => 'ASC',
    'post_status'     => 'publish'
  );
  $xml_array = get_posts( $args );
  
  // create options array
  $options = '';
  if ($xml_array) {
    foreach ($xml_array as $entry) {
      $options .= '<option value="'. $entry->ID .'" '. (!empty($saved_options) && in_array($entry->ID, $saved_options) ? 'selected="selected"' : '') .'>'. $entry->post_title.'</option>';
    }
  }
  wp_reset_postdata();
  wp_reset_query();
  
  echo '
    <div class="options_group">
      <p class="form-field wooxml_exclude_field ">
        <label for="wooxml_exclude">'. __( 'Exclude from WOO Feeds', 'wxf') .'</label>
        <select id="wooxml_exclude" name="wooxml_exclude[]" class="select short selectwoo" multiple>
          '. $options .'
        </select>
      </p>
    </div>
    <script>
      jQuery(document).ready(function() {
        jQuery("#wooxml_exclude").selectWoo();
      });
    </script>
    ';
    
    echo '<div class="options_group">';
  
  woocommerce_wp_select(
      array( 
        'id'      => 'wooxml_attributes_implode', 
        'label'   => __( 'One product per variable product', 'wxf' ), 
        'options' => array(
          'default' => __( 'Default', 'wxf' ),
          'yes'     => __( 'Yes', 'wxf' ),
          'no'      => __( 'No', 'wxf' )
          ),
        'desc_tip'    => 'true',
        'description'   => __( 'Create one product per variable product. Add all attributes in a comma separated tag', 'wxf' ),   
        )
      );
    
    woocommerce_wp_text_input( 
    array( 
        'id'          => 'wooxml_price', 
        'label'       => __( 'Default product price', 'wxf' ), 
        'desc_tip'    => 'true',
        'description' => __( 'Price for joined attribute tags', 'wxf' )
      )
    );
    
    echo '</div>';
	
}


// Save Fields
add_action( 'woocommerce_process_product_meta', 'wooxml_add_custom_general_fields_save' );
function wooxml_add_custom_general_fields_save( $post_id ){
  // Save wooxml_exclude
	$wooxml_exclude = ( isset( $_POST['wooxml_exclude'] ) ? $_POST['wooxml_exclude'] : false );
	$wooxml_price = $_POST['wooxml_price'];
	$wooxml_attributes_implode = $_POST['wooxml_attributes_implode'];
  
	if( !empty( $wooxml_exclude ) ) {
		update_post_meta( $post_id, 'wooxml_exclude', $wooxml_exclude );
	} else {
		delete_post_meta( $post_id, 'wooxml_exclude' );
	}
	if( !empty( $wooxml_price ) ) {
		update_post_meta( $post_id, 'wooxml_price', $wooxml_price );
	} else {
		delete_post_meta( $post_id, 'wooxml_price' );
	}
	if( !empty( $wooxml_attributes_implode ) ) {
		update_post_meta( $post_id, 'wooxml_attributes_implode', $wooxml_attributes_implode );
	} else {
		delete_post_meta( $post_id, 'wooxml_attributes_implode' );
	}
}

